package javax.swing.colorchooser;

import javax.swing.event.ChangeListener;
import java.awt.Color;
import javax.swing.event.EventListenerList;
import javax.swing.event.ChangeEvent;
import java.io.Serializable;

public class DefaultColorSelectionModel implements ColorSelectionModel, Serializable
{
    protected transient ChangeEvent changeEvent;
    protected EventListenerList listenerList;
    private Color selectedColor;
    
    public DefaultColorSelectionModel() {
        this.changeEvent = null;
        this.listenerList = new EventListenerList();
        this.selectedColor = Color.white;
    }
    
    public DefaultColorSelectionModel(Color selectedColor) {
        this.changeEvent = null;
        this.listenerList = new EventListenerList();
        this.selectedColor = selectedColor;
    }
    
    @Override
    public Color getSelectedColor() {
        return this.selectedColor;
    }
    
    @Override
    public void setSelectedColor(Color color) {
        if (color != null && !this.selectedColor.equals(color)) {
            this.selectedColor = color;
            this.fireStateChanged();
        }
    }
    
    @Override
    public void addChangeListener(ChangeListener l) {
        this.listenerList.add(ChangeListener.class, l);
    }
    
    @Override
    public void removeChangeListener(ChangeListener l) {
        this.listenerList.remove(ChangeListener.class, l);
    }
    
    public ChangeListener[] getChangeListeners() {
        return (ChangeListener[])this.listenerList.getListeners(ChangeListener.class);
    }
    
    protected void fireStateChanged() {
        Object[] listenerList = this.listenerList.getListenerList();
        for (int i = listenerList.length - 2; i >= 0; i -= 2) {
            if (listenerList[i] == ChangeListener.class) {
                if (this.changeEvent == null) {
                    this.changeEvent = new ChangeEvent(this);
                }
                ((ChangeListener)listenerList[i + 1]).stateChanged(this.changeEvent);
            }
        }
    }
}
